@@ -93,7 +93,7 @@ struct compare_bones
 void
 ValueNode_Bone::show_bone_map(Canvas::LooseHandle canvas, const char *file, int line, String text, Time t)
 {
-	if (!getenv("SYNFIG_DEBUG_BONE_MAP")) return;
+	if (!DEBUG_GETENV("SYNFIG_DEBUG_BONE_MAP")) return;
 
 	BoneMap bone_map(canvas_map[canvas]);
 
@@ -142,7 +142,7 @@ ValueNode_Bone::get_ordered_bones(etl::handle<const Canvas> canvas)
 			BoneSet ref(get_bones_referenced_by(user, false));
 			if (ref.empty())
 			{
-				if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d %s doesn't need anybody\n", __FILE__, __LINE__,
+				DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d %s doesn't need anybody\n", __FILE__, __LINE__,
 					   user->get_bone_name(0).c_str());
 				current_list.push_back(user);
 			}
@@ -150,7 +150,7 @@ ValueNode_Bone::get_ordered_bones(etl::handle<const Canvas> canvas)
 				for(BoneSet::iterator iter=ref.begin();iter!=ref.end();++iter)
 				{
 					ValueNode_Bone::Handle used(*iter);
-					if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d %s is used by %s\n", __FILE__, __LINE__,
+					DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d %s is used by %s\n", __FILE__, __LINE__,
 																				   used->get_bone_name(0).c_str(),
 																				   user->get_bone_name(0).c_str());
 					is_used_by.insert(make_pair(used, user));
@@ -165,12 +165,12 @@ ValueNode_Bone::get_ordered_bones(etl::handle<const Canvas> canvas)
 
 	while (current_list.size())
 	{
-		if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d current_list has %zd members; we have %zd in is_used_by and %zd in uses\n",
+		DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d current_list has %zd members; we have %zd in is_used_by and %zd in uses\n",
 																	   __FILE__, __LINE__, current_list.size(), is_used_by.size(), uses.size());
 		for(BoneList::iterator iter=current_list.begin();iter!=current_list.end();++iter)
 		{
 			ValueNode_Bone::Handle bone(*iter);
-			if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d bone: %s\n", __FILE__, __LINE__, bone->get_bone_name(0).c_str());
+			DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d bone: %s\n", __FILE__, __LINE__, bone->get_bone_name(0).c_str());
 			ret.push_back(bone);
 
 			std::multimap<ValueNode_Bone::Handle, ValueNode_Bone::Handle>::iterator begin(is_used_by.lower_bound(bone));
@@ -178,10 +178,10 @@ ValueNode_Bone::get_ordered_bones(etl::handle<const Canvas> canvas)
 			for (std::multimap<ValueNode_Bone::Handle, ValueNode_Bone::Handle>::iterator iter = begin; iter != end; iter++)
 			{
 				ValueNode_Bone::Handle user(iter->second);
-				if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("\t\t\t%s:%d user: %s\n", __FILE__, __LINE__, user->get_bone_name(0).c_str());
+				DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "\t\t\t%s:%d user: %s\n", __FILE__, __LINE__, user->get_bone_name(0).c_str());
 
 				// erase (user,bone) from uses
-				if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d trying to erase - searching %zd\n", __FILE__, __LINE__, uses.count(user));
+				DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d trying to erase - searching %zd\n", __FILE__, __LINE__, uses.count(user));
 				std::multimap<ValueNode_Bone::Handle, ValueNode_Bone::Handle>::iterator begin2(uses.lower_bound(user));
 				std::multimap<ValueNode_Bone::Handle, ValueNode_Bone::Handle>::iterator end2(uses.upper_bound(user));
 				std::multimap<ValueNode_Bone::Handle, ValueNode_Bone::Handle>::iterator iter2;
@@ -190,24 +190,24 @@ ValueNode_Bone::get_ordered_bones(etl::handle<const Canvas> canvas)
 					if (iter2->second == bone)
 					{
 						uses.erase(iter2);
-						if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d found it\n", __FILE__, __LINE__);
+						DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d found it\n", __FILE__, __LINE__);
 						break;
 					}
 					else
 					{
-						if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("no\n");
+						DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "no\n");
 					}
 				}
 				if (iter2 == end2)
 				{
-					if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d didn't find it?!?\n", __FILE__, __LINE__);
+					DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d didn't find it?!?\n", __FILE__, __LINE__);
 					assert(0);
 				}
 
-				if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("%s:%d now there are %zd\n", __FILE__, __LINE__, uses.count(user));
+				DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "%s:%d now there are %zd\n", __FILE__, __LINE__, uses.count(user));
 				if (uses.count(user) == 0)
 				{
-					if (getenv("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS")) printf("\t\t\t%s:%d adding %s\n", __FILE__, __LINE__, user->get_bone_name(0).c_str());
+					DEBUG_LOG("SYNFIG_DEBUG_ORDER_BONES_FOR_SAVE_CANVAS", "\t\t\t%s:%d adding %s\n", __FILE__, __LINE__, user->get_bone_name(0).c_str());
 					new_list.push_back(user);
 				}
 			}
@@ -229,14 +229,14 @@ ValueNode_Bone::ValueNode_Bone():
 {
 	Vocab ret(get_children_vocab());
 	set_children_vocab(ret);
-	if (getenv("SYNFIG_DEBUG_ROOT_BONE"))
-		printf("%s:%d ValueNode_Bone::ValueNode_Bone() this line should only appear once guid %s\n", __FILE__, __LINE__, get_guid().get_string().c_str());
+	DEBUG_LOG("SYNFIG_DEBUG_ROOT_BONE",
+		"%s:%d ValueNode_Bone::ValueNode_Bone() this line should only appear once guid %s\n", __FILE__, __LINE__, get_guid().get_string().c_str());
 }
 
 ValueNode_Bone::ValueNode_Bone(const ValueBase &value, etl::loose_handle<Canvas> canvas):
 	LinkableValueNode(value.get_type())
 {
-	if (getenv("SYNFIG_DEBUG_BONE_CONSTRUCTORS"))
+	if (DEBUG_GETENV("SYNFIG_DEBUG_BONE_CONSTRUCTORS"))
 	{
 		printf("\n%s:%d ------------------------------------------------------------------------\n", __FILE__, __LINE__);
 		printf("%s:%d --- ValueNode_Bone() for %s at %lx---\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), uintptr_t(this));
@@ -270,12 +270,12 @@ ValueNode_Bone::ValueNode_Bone(const ValueBase &value, etl::loose_handle<Canvas>
 		if (!parent) parent = get_root_bone();
 		set_link("parent",ValueNode_Const::create(ValueNode_Bone::Handle::cast_const(parent)));
 
-		if (getenv("SYNFIG_DEBUG_BONE_MAP"))
-			printf("%s:%d adding to canvas_map\n", __FILE__, __LINE__);
+		DEBUG_LOG("SYNFIG_DEBUG_BONE_MAP",
+			"%s:%d adding to canvas_map\n", __FILE__, __LINE__);
 		canvas_map[get_root_canvas()][get_guid()] = this;
 
-		if (getenv("SYNFIG_DEBUG_SET_PARENT_CANVAS"))
-			printf("%s:%d set parent canvas for bone %lx to %lx\n", __FILE__, __LINE__, uintptr_t(this), uintptr_t(canvas.get()));
+		DEBUG_LOG("SYNFIG_DEBUG_SET_PARENT_CANVAS",
+			"%s:%d set parent canvas for bone %lx to %lx\n", __FILE__, __LINE__, uintptr_t(this), uintptr_t(canvas.get()));
 		set_parent_canvas(canvas);
 
 		show_bone_map(get_root_canvas(), __FILE__, __LINE__, strprintf("in constructor of %s at %lx", GET_GUID_CSTR(get_guid()), uintptr_t(this)));
@@ -288,8 +288,8 @@ ValueNode_Bone::ValueNode_Bone(const ValueBase &value, etl::loose_handle<Canvas>
 
 void ValueNode_Bone::on_changed()
 {
-	if (getenv("SYNFIG_DEBUG_ON_CHANGED"))
-		printf("%s:%d ValueNode_Bone::on_changed()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ON_CHANGED",
+		"%s:%d ValueNode_Bone::on_changed()\n", __FILE__, __LINE__);
 
 	LinkableValueNode::on_changed();
 }
@@ -308,15 +308,15 @@ ValueNode_Bone::create(const ValueBase &x, Canvas::LooseHandle canvas)
 
 ValueNode_Bone::~ValueNode_Bone()
 {
-	if (getenv("SYNFIG_DEBUG_BONE_CONSTRUCTORS"))
+	if (DEBUG_GETENV("SYNFIG_DEBUG_BONE_CONSTRUCTORS"))
 	{
 		printf("\n%s:%d ------------------------------------------------------------------------\n", __FILE__, __LINE__);
 		printf("%s:%d --- ~ValueNode_Bone() for %s at %lx---\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), uintptr_t(this));
 		printf("%s:%d ------------------------------------------------------------------------\n\n", __FILE__, __LINE__);
 	}
 
-	if (getenv("SYNFIG_DEBUG_BONE_MAP"))
-		printf("%s:%d removing from canvas_map\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_MAP",
+		"%s:%d removing from canvas_map\n", __FILE__, __LINE__);
 	canvas_map[get_root_canvas()].erase(get_guid());
 
 	show_bone_map(get_root_canvas(), __FILE__, __LINE__, "in destructor");
@@ -354,8 +354,8 @@ ValueNode_Bone::set_root_canvas(etl::loose_handle<Canvas> canvas)
 		show_bone_map(new_canvas, __FILE__, __LINE__, strprintf("after changing canvas from %lx to %lx", uintptr_t(old_canvas.get()), uintptr_t(new_canvas.get())));
 	}
 	else
-		if (getenv("SYNFIG_DEBUG_BONE_MAP"))
-			printf("%s:%d canvases are the same\n", __FILE__, __LINE__);
+		DEBUG_LOG("SYNFIG_DEBUG_BONE_MAP",
+			"%s:%d canvases are the same\n", __FILE__, __LINE__);
 }
 
 //!Animated Transformation matrix.
@@ -386,7 +386,7 @@ ValueNode_Bone::get_animated_matrix(Time t, Real scalex, Real scaley, Angle angl
 			   * Matrix().set_rotate(angle)
 			   * Matrix().set_scale(scalex,scaley);
 
-	if (getenv("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION"))
+	if (DEBUG_GETENV("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION"))
 	{
 		printf("%s  *\n", Matrix().set_scale(scalex, scaley).get_string(18, "animated_matrix = ",
 																		strprintf("scale(%7.2f, %7.2f) (%s)", scalex, scaley,
@@ -426,8 +426,8 @@ ValueNode_Bone::get_parent(Time t)const
 ValueBase
 ValueNode_Bone::operator()(Time t)const
 {
-	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
-		printf("%s:%d operator()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_VALUENODE_OPERATORS",
+		"%s:%d operator()\n", __FILE__, __LINE__);
 
 //	show_bone_map(get_root_canvas(), __FILE__, __LINE__, strprintf("in op() at %s", t.get_string().c_str()), t);
 
@@ -442,9 +442,9 @@ ValueNode_Bone::operator()(Time t)const
 	Real   bone_width			((*width_	)(t).get(Real()));
 	Real   bone_tipwidth		((*tipwidth_)(t).get(Real()));
 	Real   bone_depth			((*depth_)(t).get(Real()));
-	if (getenv("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION")) printf("\n***\n*** %s:%d get_animated_matrix() for %s\n***\n\n", __FILE__, __LINE__, get_bone_name(t).c_str());
+	DEBUG_LOG("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION", "\n***\n*** %s:%d get_animated_matrix() for %s\n***\n\n", __FILE__, __LINE__, get_bone_name(t).c_str());
 	Matrix bone_animated_matrix	(get_animated_matrix(t, bone_scalex, 1.0, bone_angle, bone_origin, bone_parent));
-	if (getenv("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION")) printf("\n***\n*** %s:%d get_animated_matrix() for %s done\n***\n\n", __FILE__, __LINE__, get_bone_name(t).c_str());
+	DEBUG_LOG("SYNFIG_DEBUG_ANIMATED_MATRIX_CALCULATION", "\n***\n*** %s:%d get_animated_matrix() for %s done\n***\n\n", __FILE__, __LINE__, get_bone_name(t).c_str());
 #endif
 
 	Bone ret;
@@ -712,34 +712,34 @@ ValueNode_Bone::is_ancestor_of(ValueNode_Bone::ConstHandle bone, Time t)const
 	ValueNode_Bone::ConstHandle ancestor(this);
 	set<ValueNode_Bone::ConstHandle> seen;
 
-	if (getenv("SYNFIG_DEBUG_ANCESTOR_CHECK"))
-		printf("%s:%d checking whether %s is ancestor of %s\n", __FILE__, __LINE__, GET_NODE_DESC_CSTR(ancestor,t), GET_NODE_DESC_CSTR(bone,t));
+	DEBUG_LOG("SYNFIG_DEBUG_ANCESTOR_CHECK",
+		"%s:%d checking whether %s is ancestor of %s\n", __FILE__, __LINE__, GET_NODE_DESC_CSTR(ancestor,t), GET_NODE_DESC_CSTR(bone,t));
 
 	while (bone != get_root_bone())
 	{
 		if (bone == ancestor)
 		{
-			if (getenv("SYNFIG_DEBUG_ANCESTOR_CHECK"))
-				printf("%s:%d bone reached us - so we are its ancestor - return true\n", __FILE__, __LINE__);
+			DEBUG_LOG("SYNFIG_DEBUG_ANCESTOR_CHECK",
+				"%s:%d bone reached us - so we are its ancestor - return true\n", __FILE__, __LINE__);
 			return bone;
 		}
 
 		if (seen.count(bone))
 		{
-			if (getenv("SYNFIG_DEBUG_ANCESTOR_CHECK"))
-				printf("%s:%d stuck in a loop - return true\n", __FILE__, __LINE__);
+			DEBUG_LOG("SYNFIG_DEBUG_ANCESTOR_CHECK",
+				"%s:%d stuck in a loop - return true\n", __FILE__, __LINE__);
 			return bone;
 		}
 
 		seen.insert(bone);
 		bone=GET_NODE_PARENT_NODE(bone,t);
 
-		if (getenv("SYNFIG_DEBUG_ANCESTOR_CHECK"))
-			printf("%s:%d step on to parent %s\n", __FILE__, __LINE__, GET_NODE_DESC_CSTR(bone,t));
+		DEBUG_LOG("SYNFIG_DEBUG_ANCESTOR_CHECK",
+			"%s:%d step on to parent %s\n", __FILE__, __LINE__, GET_NODE_DESC_CSTR(bone,t));
 	}
 
-	if (getenv("SYNFIG_DEBUG_ANCESTOR_CHECK"))
-		printf("%s:%d reached root - return false\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ANCESTOR_CHECK",
+		"%s:%d reached root - return false\n", __FILE__, __LINE__);
 	return 0;
 }
 
@@ -806,8 +806,8 @@ ValueNode_Bone::get_bones_referenced_by(ValueNode::Handle value_node, bool recur
 	{
 		// todo: while loading we might be setting up an ancestry loop by ignoring the placeholder valuenode here
 		// can we check for loops in badly formatted .sifz files somehow?
-		if (getenv("SYNFIG_DEBUG_PLACEHOLDER_VALUENODE"))
-			printf("%s:%d found a placeholder - skipping loop check\n", __FILE__, __LINE__);
+		DEBUG_LOG("SYNFIG_DEBUG_PLACEHOLDER_VALUENODE",
+			"%s:%d found a placeholder - skipping loop check\n", __FILE__, __LINE__);
 		return ret;
 	}
 
@@ -822,10 +822,7 @@ ValueNode_Bone::get_bones_affected_by(ValueNode::Handle value_node)
 	BoneSet ret;
 	set<const Node*> seen, current_nodes, new_nodes;
 	int generation = 0;
-	bool debug(false);
-
-	if (getenv("SYNFIG_DEBUG_SUITABLE_PARENTS"))
-		debug = true;
+	bool debug = DEBUG_GETENV("SYNFIG_DEBUG_SUITABLE_PARENTS");
 
 	if (debug) printf("getting bones affected by %lx %s\n", uintptr_t(value_node.get()), value_node->get_string().c_str());
 
@@ -874,10 +871,7 @@ ValueNode_Bone::BoneSet
 ValueNode_Bone::get_possible_parent_bones(ValueNode::Handle value_node)
 {
 	BoneSet ret;
-	bool debug(false);
-
-	if (getenv("SYNFIG_DEBUG_SUITABLE_PARENTS"))
-		debug = true;
+	bool debug = DEBUG_GETENV("SYNFIG_DEBUG_SUITABLE_PARENTS");
 
 	if (debug) printf("%s:%d which bones can be parents of %lx (%s)\n", __FILE__, __LINE__, uintptr_t(value_node.get()), value_node->get_string().c_str());
 
@@ -1018,8 +1012,8 @@ ValueNode_Bone::fix_bones_referenced_by(ValueNode::Handle value_node, ValueNode:
 void
 ValueNode_Bone::ref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s   ref valuenode_bone %*s -> %2d\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), (count()*2), "", count()+1);
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s   ref valuenode_bone %*s -> %2d\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), (count()*2), "", count()+1);
 
 	LinkableValueNode::ref();
 }
@@ -1027,8 +1021,8 @@ ValueNode_Bone::ref()const
 bool
 ValueNode_Bone::unref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s unref valuenode_bone %*s%2d <-\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), ((count()-1)*2), "", count()-1);
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s unref valuenode_bone %*s%2d <-\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), ((count()-1)*2), "", count()-1);
 
 	return LinkableValueNode::unref();
 }
@@ -1036,25 +1030,25 @@ ValueNode_Bone::unref()const
 void
 ValueNode_Bone::rref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s               rref valuenode_bone %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s               rref valuenode_bone %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
 
 	LinkableValueNode::rref();
 
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%d\n", rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%d\n", rcount());
 }
 
 void
 ValueNode_Bone::runref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s             runref valuenode_bone %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s             runref valuenode_bone %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
 
 	LinkableValueNode::runref();
 
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%d\n", rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%d\n", rcount());
 }
 #endif
 
@@ -1062,14 +1056,14 @@ ValueNode_Bone::runref()const
 
 ValueNode_Bone_Root::ValueNode_Bone_Root()
 {
-	if (getenv("SYNFIG_DEBUG_ROOT_BONE"))
-		printf("%s:%d ValueNode_Bone_Root::ValueNode_Bone_Root()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ROOT_BONE",
+		"%s:%d ValueNode_Bone_Root::ValueNode_Bone_Root()\n", __FILE__, __LINE__);
 }
 
 ValueNode_Bone_Root::~ValueNode_Bone_Root()
 {
-	if (getenv("SYNFIG_DEBUG_ROOT_BONE"))
-		printf("%s:%d ValueNode_Bone_Root::~ValueNode_Bone_Root()\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ROOT_BONE",
+		"%s:%d ValueNode_Bone_Root::~ValueNode_Bone_Root()\n", __FILE__, __LINE__);
 }
 
 ValueBase
@@ -1084,16 +1078,16 @@ ValueNode_Bone_Root::operator()(Time t __attribute__ ((unused)))const
 void
 ValueNode_Bone_Root::set_guid(const GUID& new_guid)
 {
-	if (getenv("SYNFIG_DEBUG_ROOT_BONE"))
-		printf("%s:%d bypass set_guid() for root bone\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ROOT_BONE",
+		"%s:%d bypass set_guid() for root bone\n", __FILE__, __LINE__);
 	LinkableValueNode::set_guid(new_guid);
 }
 
 void
 ValueNode_Bone_Root::set_root_canvas(etl::loose_handle<Canvas> canvas)
 {
-	if (getenv("SYNFIG_DEBUG_ROOT_BONE"))
-		printf("%s:%d bypass set_root_canvas() for root bone\n", __FILE__, __LINE__);
+	DEBUG_LOG("SYNFIG_DEBUG_ROOT_BONE",
+		"%s:%d bypass set_root_canvas() for root bone\n", __FILE__, __LINE__);
 	LinkableValueNode::set_root_canvas(canvas);
 }
 
@@ -1140,8 +1134,8 @@ ValueNode_Bone_Root::check_type(Type &type __attribute__ ((unused)))
 void
 ValueNode_Bone_Root::ref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s   ref valuenode_bone_root %*s -> %2d\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), (count()*2), "", count()+1);
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s   ref valuenode_bone_root %*s -> %2d\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), (count()*2), "", count()+1);
 
 	LinkableValueNode::ref();
 }
@@ -1149,8 +1143,8 @@ ValueNode_Bone_Root::ref()const
 bool
 ValueNode_Bone_Root::unref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s unref valuenode_bone_root %*s%2d <-\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), ((count()-1)*2), "", count()-1);
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s unref valuenode_bone_root %*s%2d <-\n", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), ((count()-1)*2), "", count()-1);
 
 	return LinkableValueNode::unref();
 }
@@ -1158,24 +1152,24 @@ ValueNode_Bone_Root::unref()const
 void
 ValueNode_Bone_Root::rref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s               rref valuenode_bone_root %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s               rref valuenode_bone_root %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
 
 	LinkableValueNode::rref();
 
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%d\n", rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%d\n", rcount());
 }
 
 void
 ValueNode_Bone_Root::runref()const
 {
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%s:%d %s             runref valuenode_bone_root %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%s:%d %s             runref valuenode_bone_root %d -> ", __FILE__, __LINE__, GET_GUID_CSTR(get_guid()), rcount());
 
 	LinkableValueNode::runref();
 
-	if (getenv("SYNFIG_DEBUG_BONE_REFCOUNT"))
-		printf("%d\n", rcount());
+	DEBUG_LOG("SYNFIG_DEBUG_BONE_REFCOUNT",
+		"%d\n", rcount());
 }
 #endif
